

;=====================================================================================
; Thomas W. Briggs
; George Mason University, Fairfax, VA, USA
;
; Copyright 2018 Thomas W. Briggs
;
; Licensed under the Apache License, Version 2.0 (the “License”);
; you may not use this file except in compliance with the License.
; You may obtain a copy of the License at
;   http://www.apache.org/licenses/LICENSE-2.0
;
;
; Corresponding author contact:  Tom Briggs - tbriggs@gmu.edu
;
;
; IF YOU USE OR EXTEND THIS MODEL, PLEASE CITE AS
;
; Associated publication:
;
; Briggs T.W. (2018) Formal Organizations, Informal Networks, and Work Flow: An Agent-Based Model.
;   In: Thomson R., Dancy C., Hyder A., Bisgin H. (eds) Social, Cultural, and Behavioral Modeling.
;   SBP-BRiMS 2018. Lecture Notes in Computer Science, vol 10899. Springer, Cham.
;   https://doi.org/10.1007/978-3-319-93372-6_21
;=====================================================================================


extensions [ nw ] ;; Networks extension

; Pseudocode explaining model set up

; For n organization size, distribute agents among levels that will make
;   up the org hierarchy
; Create a "tree" hierarchy representing the formal organizational chart and create links
;   that "draw the lines" of the org chart

globals [
  created-workjobs   ;; tracker for number of workjobs created
  completed-workjobs ;; tracker for number of workjobs completed
  informal-link-passes ;; tracker for number of workjobs passed across an informal link
  skip-hierarchy-passes ;; tracker for number of workjobs that skipped a level in chain of command
  global-task-alive-time
  global-task-work-needed
  ;; seed ;; input a seed value to make model reproducible
]

;; AGENTS
;;   breed "employee" is the workers in the organization, each with a "level" variable
;;   that can be used as a measure of distance to the CEO
breed [ employees employee ]
;;   breed workjob is an agent object that will represent tasks/work assignments
breed [ workjobs workjob ]

;; TURTLES-OWN / INSTANCE VARIABLES
employees-own [
  level       ;; level in org hierarchy
  middle-manager ;; Boolean - true if agent is a middle manager
  in-queue    ;; items in queue
  queue-max   ;; max queue
  current-workload ;; hours of work for jobs in queue
  busy-status ;; Boolean - true if busiest among peers; false otherwise
]

;; JOBS-OWN / INSTANCE VARIABLES
workjobs-own [
  owner            ;; employee who currently owns me (also available through assignedjob directed link)
  original-difficulty ;; save the original difficulty/work-needed value
  work-needed ;; integer to represent how easy or difficult the task is - how much "work" it needs
  management-work-needed ;; some percentage of the overall work needed to represent the manager's handling/shaping of the task
  ;; variables for tracking
  location-tracker ;; what level of the organization is the work currently at?
  ticks-alive      ;; track how long the workjob has been "alive" to measure efficiency
  wait-tracker     ;; track how long the workjob waited because intended target unavailable
  formal-link-passes  ;; track the number of handoffs
]

;; LINKS IN THIS MODEL

;;  representing the FORMAL NETWORK in the organization
directed-link-breed [ manages manage ]                ;; Hierarchical manages/managed by relationship
undirected-link-breed [ lateral-links lateral-link ]  ;; Lateral links between peers managed by same manager

;;  representing the INFORMAL NETWORK in the organization
undirected-link-breed [ friendships friendship ]      ;; Informal relationships between organization members

;;  representing RECEIPT OF A WORKJOB OBJECT
directed-link-breed [ assignedjobs assignedjob ]


to SETUP  ;; SETUP BUTTON
  clear-all
  random-seed read-from-string seed
  reset-ticks
  ;; set some default shapes/colors
  set-default-shape employees "circle 2" ;; "circle 2" ;; interesting possible visualization option
  create-organization ;; creates hierarchy
  create-lateral-links-in-org  ;; creates links between team members
  if (informal-links) [
    add-friendship-network ]
  color-organization
  layout-radial employees manages one-of employees with [ level = 0 ]  ;; probably the best layout available
  update-labels
end

to GO  ;; GO BUTTON
  work
  do-business
  ask workjobs [ set ticks-alive ticks-alive + 1 ]
  update-labels
  tick
end

to update-labels
  if (set-label = "NONE") [
    ask employees [
      set label "" ]
    ask workjobs [
      set label "" ]
  ]
  if (set-label = "Current-workload") [
    ask employees [
      set label current-workload ]
    ]
  if (set-label = "Items-in-queue") [
    ask employees [
      set label in-queue ]
  ]
  if (set-label = "Workjob ID") [
    ask workjobs [
      set label who ]
  ]
end

;; SETUP PROCEDURES
to create-organization
  ;; create a single CEO (CEO = employee Level 0)
  create-employees 1 [
    set level 0
    set queue-max -1
    ]

  ;; use a series of loops to populate the organizational hierarchy, limited by the max span of control

  ;; first, create executives below the CEO (executive = employee Level 1)
  let i 0
  while [ ( i < span-of-control ) ] [ ;; and ( count employees < organization-size ) ] [
    set i i + 1
    create-employees 1 [
      set level 1
      create-manage-from one-of employees with [ level = 0 ]
      ;; set xcor random-xcor
      ;; set ycor random-ycor
    ]

    ;; next, create managers below each executive (manager = employee Level 2)
    let j 0
    while [ ( j < span-of-control) ] [ ;; and ( count employees < organization-size ) ] [
      set j j + 1
      create-employees 1 [ create-manage-from ( max-one-of employees with [ level = 1 ]  [ who ] )
                          set middle-manager TRUE
                          set level 2
                          set xcor random-xcor
                          set ycor random-ycor
                        ]

      ]

    ]
end

;; link every member of every "team" (i.e., every person under a given manager knows everyone else under that manager)
to create-lateral-links-in-org
  ask employees [
    ;; temporary agent set that holds the OUT-link-neighbors of the current turtle (i.e., all subordinates)
    let tempset out-link-neighbors
    ;; ask every turtle in the temp agent set to create a "lateral link" with every other turtle in that agentset
    ;;   (i.e., every other turtle on the same team)
    ask tempset [ create-lateral-links-with other tempset ]
  ]
end

;; color turtles by their level in the organizaton for easier visualization
to color-organization
  ask employees with [ level = 0 ] [ set color white ]
  ask employees with [ level = 1 ] [ set color grey ]
  ask employees with [ level = 2 ] [ set color red ]
;  ask employees with [ level = 3 ] [ set color blue ]
;  ask employees with [ level = 4 ] [ set color green ]
end


to seed-workjobs
  ask employees [
    while [ current-workload < assign-work-up-to-what-avg ] [
      create-new-workjobs
    ]
  ]
end

;; create new "job" ("jobs" are also agents)
to create-new-workjobs
  hatch 1 [
    set breed workjobs
    set shape "dot"
    set color grey
    set owner myself
    align-to-owner
    create-assignedjob-to myself ;; create network link
    set created-workjobs created-workjobs + 1
    set work-needed random 100 + 1
    set management-work-needed work-needed * bottleneck / 2 ;; mgmt spends 1/2 of their required time before assigning and 1/2 after getting it back
    set original-difficulty work-needed
    ;; set wait-tracker 0
  ]
  update-current-workload
end

to offset-workjobs ;; to make visualization easier, have the job move itself 0.5 in a random direction so it will cluster *around* the employee where it's locate
  set heading random 360
  fd 0.5
end


;; NETWORK ADDITIONS

;; Erdos-Renyi random network
to add-friendship-network
  ; CITATION - following code adapted from Adamic, L. (2012) adaptation of Wilensky, U. (2005)
let thiswho 0
let prob-link 0.01
     ask employees [
     set thiswho who
       ask other employees with [who > thiswho] [
       if (random-float 1 < prob-informal-link) [
         create-friendship-with myself
       ]
     ]
   ]
     ask friendships [
       set color 97
     ]
;; END CITATION
end



;; MODEL ACTION

;; run the business - create new work
to do-business
  while [ average-workload <= assign-work-up-to-what-avg ] [
    ask employee 0 [
      create-new-workjobs ]
  ]
end

;; the work moves around the organization
to work
  if any? workjobs [ ;; if any jobs are alive

    ;; jobs are agents, so they will "find" their way along the org hierarchy
    ask workjobs [

  ;; psuedocode
    ;; any employee CAN work on a task, but tasks are preferentially moved downward because there SHOULD be the most bandwidth at the bottom (right?)
    ;; if the neighbors of the employee here have more bandwidth, move to one of them

    ifelse (work-needed-here?) ;; work-needed-here? refers to whether the job needs more work at the current org level (manager or worker)
      [
      work-on-me ;; if work needed here, do it
      ]
      ;; else
      [
      try-to-move-me ;; if no more work needed here (i.e., work at this level is done), try to move me up or down
      ]
    ]
  ]
end

to-report work-needed-here?
  if (location-tracker = 0) [ report FALSE ]
  if (location-tracker = 1) [
    if management-work-needed > 0 [ report TRUE ]
    if management-work-needed <= 0 [ report FALSE ]
  ]
  if (location-tracker = 2) [
    if work-needed > 0 [ report TRUE ]
    if work-needed <= 0 [ report FALSE ]
  ]
end

to work-on-me
  if ( [ level ] of owner = 1 ) [ ;; management work
    let fractionofwork ( [ mynumjobs ] of owner ) ;; this individual only devotes a fraction of his/her effort to this job
    set management-work-needed management-work-needed - (8 / fractionofwork )
  ]
  if ( [ level ] of owner = 2 ) [ ;; employee work
    let fractionofwork ( [ mynumjobs ] of owner ) ;; ;; this individual only devotes a fraction of his/her effort to this job
    set work-needed work-needed - ( 8 / fractionofwork )
  ]
  ask owner [ update-current-workload ]
end

;; in the event that no more work is needed at the current level, try to move the job where it needs to be next (down or up)
to try-to-move-me

  ;; IF EMPLOYEE-LEVEL WORK INCOMPLETE, MOVE ME *DOWN* THE CHAIN
  if (work-needed > 0) [
    ;; move me down the chain...
     ask one-of out-assignedjob-neighbors [
            ;; create an agentset of people the employee manages who are available
            let teamMembers out-manage-neighbors
            ;; if any found
            if any? teamMembers [
              let newowner one-of teamMembers
              ;; first, have the job agent take action
                ask myself [
                ;; kill the link to the employee who was working on me
                ask my-out-assignedjobs [ die ]
                ;; increment my location tracker
                create-assignedjob-to newowner
                set owner newowner
                align-to-owner
  ;; Middle-managers touch work on the way down and on the way back up, so
  ;;   use bottleneck parameter * 1/2 * original-difficulty of work to determine
  ;;   how much time they will spend reviewing it on the way back up (i.e., half the original time
  ;;   they spent on it)
                if ( [ level ] of owner = 2 ) [
                  set management-work-needed original-difficulty * bottleneck / 2 ;; * 0.5 ;; NOTE:  for parsimony, managers will divide their time on task evenly before and
                  ;; after employees work on it

              ]
          ]
        ]
  ]
  ]

  ;; IF EMPLOYEE-LEVEL WORK COMPLETE, MOVE ME UP THE CHAIN
  if (work-needed <= 0) [
    ask one-of out-assignedjob-neighbors [
      let boss in-manage-neighbors
      if any? boss [
        let newowner one-of boss
        ask newowner [
          update-busy-status ;; CEO is always set to "FALSE"
        ]

        ;; IF BOSS IS AVAILABLE, PASS THE JOB BACK UP
        if ([busy-status] of newowner = FALSE) [
               ask myself [
                    ask my-out-assignedjobs [ die ] ;; kill the link to the employee who was working on me
                    create-assignedjob-to newowner
                    set owner newowner
                    align-to-owner
                    ;; if completed job back at CEO, it dies
                    if (location-tracker = 0) [
                      set completed-workjobs completed-workjobs + 1
                      save-my-data
                      die
                    ]
                ]
        ]

    ;; IF BOSS IS BUSY...
    if ([busy-status] of newowner = TRUE) [

      ;; FIRST try skipping the boss and going directly up, but constrained by upward-constraint parameter
      let rand random-float 1.0
      ;; IF ELSE
      ifelse (rand > upward-transmission-constraint)
      [
        ask myself [
          let temp location-tracker - 2
          let recipient one-of employees with [ level = temp ]
          ;; kill the link to the employee who was working on me
                ask my-out-assignedjobs [ die ]
                ;; increment my location tracker
                create-assignedjob-to recipient
                set owner recipient
                set skip-hierarchy-passes skip-hierarchy-passes + 1
                set color red
                ifelse (pen-draw-for-job-passing)
                [
                pen-down
                align-to-owner
                pen-up
                ]
                [ align-to-owner ]
                ;; set informal-link-passes informal-link-passes + 1
                ;; if completed job back at CEO, it dies
                if (location-tracker = 0) [
                  set completed-workjobs completed-workjobs + 1
                  save-my-data
                  die
                ]
          ]
        ]
      ;; ELSE TRY PASSING THE JOB TO SOMEONE ELSE ON MY NETWORK WHO ISN'T BUSY
        [
        ask myself [
          ask owner [
            ;; try my informal network, if I have any connections
            if any? friendship-neighbors with [ level = 2 ] [
              let leastbusy min-one-of friendship-neighbors [ current-workload ]
              ;; found a connection who is not terribly busy, so phoning a friend
              ask myself [
              ;; kill the link to the employee who was working on me
                    ask my-out-assignedjobs [ die ]
                    ;; increment my location tracker
                    create-assignedjob-to leastbusy
                    set owner leastbusy
                    set color yellow
                    ifelse (pen-draw-for-job-passing)
                    ;; IF
                    [
                    pen-down
                    align-to-owner
                    pen-up
                    ]
                    ;; ELSE
                    [ align-to-owner ]
                    set informal-link-passes informal-link-passes + 1
                    ;; if completed job back at CEO, it dies
                    if (location-tracker = 0) [
                      set completed-workjobs completed-workjobs + 1
                      save-my-data
                      die
                    ]
              ]
            ]

             if not any? friendship-neighbors [
               ask myself [
                 set wait-tracker wait-tracker + 1
               ]
             ]

           ]
         ]
        ] ;; closes ifelse
    ]
      ]
    ]
  ]
end

;; assess busy status to determine if workjob can be received
;;   --could be refined to be a measure of that individual's work, not necessarily a comparison to other similar employees,
;;     but this might require some stochasticity in job assignment so that some teams are more burdened than others
to update-busy-status
  ifelse (level = 0)
  [ set busy-status FALSE ]
  [ ;; 4/18
    let temp [ current-workload ] of max-one-of lateral-link-neighbors [ current-workload ]
    ifelse (current-workload > temp)
    [ set busy-status TRUE ]
    [ set busy-status FALSE ]
  ]
end

to align-to-owner
  setxy ([ xcor ] of owner) ([ ycor ] of owner)
  set location-tracker [ level ] of owner
  if (offset-workjobs?) [
     offset-workjobs
   ]
  ask owner [ update-current-workload ]
end

to-report mynumjobs
  report count my-in-assignedjobs
end

to update-current-workload
  set current-workload round (sum [ work-needed ] of in-assignedjob-neighbors)

end

to-report get-current-workload
  update-current-workload
  report current-workload
end

to-report average-workload
  report mean [ current-workload ] of employees
end

to save-my-data
  set global-task-alive-time global-task-alive-time + ticks-alive
  set global-task-work-needed global-task-work-needed + original-difficulty
end
@#$#@#$#@
GRAPHICS-WINDOW
399
10
838
470
16
16
13.0
1
10
1
1
1
0
0
0
1
-16
16
-16
16
0
0
1
time
30.0

BUTTON
135
283
201
316
NIL
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
12
24
200
57
span-of-control
span-of-control
1
50
7
1
1
NIL
HORIZONTAL

MONITOR
436
479
486
524
org size
count employees
17
1
11

BUTTON
206
283
269
316
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
7
109
236
142
bottleneck
bottleneck
0
1
0.73
0.01
1
NIL
HORIZONTAL

MONITOR
888
328
980
373
jobs active
count workjobs
17
1
11

BUTTON
272
283
335
316
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
489
479
555
524
avg wkld
(average-workload)
17
1
11

SLIDER
7
215
245
248
assign-work-up-to-what-avg
assign-work-up-to-what-avg
1
200
42
1
1
NIL
HORIZONTAL

MONITOR
888
375
981
420
jobs created
created-workjobs
17
1
11

MONITOR
889
422
981
467
jobs completed
completed-workjobs
17
1
11

TEXTBOX
13
96
390
118
Set %age of each task mgmt must ALSO spend on it (assigning, reviewing, etc):
9
0.0
1

SWITCH
8
336
170
369
offset-workjobs?
offset-workjobs?
0
1
-1000

SLIDER
7
249
177
282
prob-informal-link
prob-informal-link
0
1
0.05
0.01
1
NIL
HORIZONTAL

PLOT
889
11
1049
161
% of jobs completed
NIL
NIL
0.0
10.0
0.0
1.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "if (created-workjobs > 0) [\n  plot ( completed-workjobs / created-workjobs )\n]"

CHOOSER
8
404
169
449
set-label
set-label
"NONE" "Current-workload" "Items-in-queue"
0

PLOT
889
163
1143
313
workload by employee level
NIL
NIL
0.0
10.0
0.0
10.0
true
true
"" ""
PENS
"workers" 1.0 0 -2674135 true "" "if any? workjobs [\nplot (mean [ current-workload ] of employees with [ level = 2 ])\n]"
"managers" 1.0 0 -955883 true "" "if any? workjobs [\nplot (mean [ current-workload ] of employees with [ level = 1 ])\n]"

MONITOR
640
479
728
524
time stuck
sum [ wait-tracker ] of workjobs
17
1
11

SWITCH
7
283
130
316
informal-links
informal-links
0
1
-1000

TEXTBOX
204
29
354
71
use to control org size & direct reports
9
0.0
1

SLIDER
7
144
236
177
upward-transmission-constraint
upward-transmission-constraint
0
1
0.95
0.01
1
NIL
HORIZONTAL

MONITOR
1000
421
1086
466
upward-skips
skip-hierarchy-passes
17
1
11

MONITOR
1088
421
1159
466
% skipped
skip-hierarchy-passes / created-workjobs
17
1
11

TEXTBOX
11
321
161
339
Visualization options:
11
0.0
1

TEXTBOX
173
343
407
376
OFF jobs appear center, ON jobs appear around; \nalso enhances pen draw when jobs passed
9
0.0
1

SWITCH
8
370
232
403
pen-draw-for-job-passing
pen-draw-for-job-passing
0
1
-1000

MONITOR
999
373
1085
418
informal-passes
informal-link-passes
17
1
11

MONITOR
1088
373
1159
418
% informal
informal-link-passes / created-workjobs
17
1
11

MONITOR
1087
326
1159
371
efficiency
global-task-work-needed / global-task-alive-time
17
1
11

PLOT
1052
10
1212
160
time stuck
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot sum [ wait-tracker ] of workjobs"

MONITOR
558
479
638
524
avg t stuck
mean [ wait-tracker ] of workjobs
17
1
11

INPUTBOX
280
216
330
276
seed
3
1
0
String

@#$#@#$#@
## WHAT IS IT?

A generalized organizational agent-based model (ABM) containing both formal organizational hierarchy and informal social networks was developed to simulate organizational processes that occur over both formal network ties and informal networks.

## HOW IT WORKS

A simulated organization is populated with employee agents at multiple levels (e.g., CEO, managers, workers) and at each time step agents carry out work tasks that require them to interact with other agents to receive and complete projects, similar in spirit to the manner in which Tsvetovat and Carley’s (2004) agents used their ego networks to gain access to needed knowledge.

## HOW TO USE IT

This model was developed with military and quasi-military organizations in mind.

Set "span of control" to determine the size of teams in the organization (currently, team size is uniform, but this could be an interesting extension to explore).

Set "bottleneck" to approximate the degree of command-and-control organization culture - how much micromanagement do individual contributors experience?

Set "prob-informal-link" to determine the degree of informal connectivity between employees (the Erdos-Renyi graph), or, alternatively, shut off the informal links completely and enforce a static, rigid, hierarchy with no information sharing outside the chain of command.

Determine whether employees are allowed - and to what degree? - to "skip" their manager, and set the "upward transmission constraint" probability from 0 (no constraint) to 1 (fully constrained).

Use "set label" and "pen drawing" options to observe, qualitatively, in the viewer as the model runs.

## THINGS TO NOTICE

The pen / drawing feature helps for qualitative observation of job passing.  In some model runs, note whether jobs are passed unidirectionally or bidirectionally between two linked agents.

## THINGS TO TRY

Some parameters can be varied while the model is continuously running.

Try changing "bottleneck" and "upward transmission constraint" to observe, in real time, what might happen if the organizational culture could be shifted with a single intervention (observe changes in output graphs).

## EXTENDING THE MODEL

See Limitations section of publication for extending / improving the model -   https://doi.org/10.1007/978-3-319-93372-6_21

## CREDITS AND REFERENCES

Adamic, L.  Erdos-Renyi NetLogo Model.  http://www.ladamic.com/netlearn/NetLogo501/ErdosRenyiDegDist.nlogo (2012)

Krackhardt,D.,Hanson,J.R.: Informal Networks:  The company behind the org chart. Harv. Bus. Rev. 71, 104–111 (1993)

Tsvetovat, M., Carley, K.M.: Modeling complex socio-technical systems using multi-agent simulation methods. Kuenstliche Intell. 2004, 23–28 (2004)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="experiment" repetitions="10" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <exitCondition>ticks = 1000</exitCondition>
    <metric>global-task-work-needed / global-task-alive-time</metric>
    <metric>completed-workjobs</metric>
    <metric>created-workjobs</metric>
    <metric>skip-hierarchy-passes / created-workjobs</metric>
    <metric>informal-link-passes / created-workjobs</metric>
    <enumeratedValueSet variable="set-label">
      <value value="&quot;NONE&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pen-draw-for-job-passing">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="informal-links">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="offset-workjobs?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="span-of-control">
      <value value="5"/>
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bottleneck">
      <value value="0.1"/>
      <value value="0.4"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="upward-transmission-constraint">
      <value value="0.9"/>
      <value value="0.99"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="prob-informal-link">
      <value value="0.01"/>
      <value value="0.02"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="assign-work-up-to-what-avg">
      <value value="150"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
